LiveTrackingScreen constructor
const
LiveTrackingScreen({
- Key? key,
Creates a live tracking screen that saves a raw path when the user taps save.
Implementation
const LiveTrackingScreen({super.key});
Creates a live tracking screen that saves a raw path when the user taps save.
const LiveTrackingScreen({super.key});