encodedPathModel property
The encoded path to render when your app stores compressed route data.
Implementation
final EncodedPathModel? encodedPathModel;
The encoded path to render when your app stores compressed route data.
final EncodedPathModel? encodedPathModel;