DistanceUtils class

Utility methods for calculating distances across a list of coordinates.

Constructors

DistanceUtils()
Creates a distance utility instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateDistance(List<LatLng> path) double
Returns the total geodesic distance of path in kilometers.